@@ -1,7 +1,18 @@
-use crate::{
-    retrieval::{fetch_entries::FetchEntries, fetch_links::FetchLinks},
-    wire_element::WireElement,
-};
+#[cfg(not(feature = "mock"))]
+use crate::retrieval::fetch_entries::FetchEntries;
+#[cfg(not(feature = "mock"))]
+use crate::retrieval::fetch_links::FetchLinks;
+#[cfg(not(feature = "mock"))]
+use crate::retrieval::get_latest_for_entry::GetLatestEntry;
+
+#[cfg(feature = "mock")]
+use crate::retrieval::fetch_entries::MockFetchEntries as FetchEntries;
+#[cfg(feature = "mock")]
+use crate::retrieval::fetch_links::MockFetchLinks as FetchLinks;
+#[cfg(feature = "mock")]
+use crate::retrieval::get_latest_for_entry::MockGetLatestEntry as GetLatestEntry;
+
+use crate::wire_element::WireElement;
 use hdk::prelude::*;
 
 #[cfg(feature = "mock")]
@@ -16,6 +27,7 @@ impl FetchAction {
         &self,
         fetch_entries: &FetchEntries,
         fetch_links: &FetchLinks,
+        get_latest: &GetLatestEntry,
         fetch_options: crate::retrieval::inputs::FetchOptions,
         get_options: GetOptions,
         path: Path,
@@ -26,7 +38,6 @@ impl FetchAction {
         T: 'static + Clone + TryFrom<SerializedBytes, Error = SerializedBytesError>,
         E: 'static,
     {
-        let get_latest = crate::retrieval::get_latest_for_entry::GetLatestEntry {};
         let entries = fetch_entries.fetch_entries::<T>(
             fetch_links,
             &get_latest,
