@@ -1,4 +1,8 @@
+#[cfg(not(feature = "mock"))]
 use crate::retrieval::get_latest_for_entry::GetLatestEntry;
+#[cfg(feature = "mock")]
+use crate::retrieval::get_latest_for_entry::MockGetLatestEntry as GetLatestEntry;
+
 use crate::wire_element::WireElement;
 use hdk::prelude::*;
 use std::convert::identity;
